16.82. cdist-type__issue(7) — cdist 6.9.8 documentation

# 16.82. cdist-type__issue(7)

## 16.82.1. NAME

cdist-type__issue - Manage issue

## 16.82.2. DESCRIPTION

This cdist type allows you to easily setup /etc/issue.

## 16.82.3. REQUIRED PARAMETERS

None.

## 16.82.4. OPTIONAL PARAMETERS

source

  If supplied, use this file as /etc/issue instead of default.

## 16.82.5. EXAMPLES

    __issue

    # When called from another type
    __issue --source "$__type/files/myfancyissue"

## 16.82.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.82.7. COPYING

Copyright (C) 2011 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.